package edu.nyu.scps.alertdialog;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

public class AlertDialogActivity extends Activity {
	static final int ALERT_DIALOG_ID = 0;
	int i = 0;
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		final Button button = (Button)findViewById(R.id.alertDialog);

		button.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				showDialog(ALERT_DIALOG_ID);
			}
		});
	}

	@Override
	protected Dialog onCreateDialog(int id, Bundle bundle) {
		final TextView textView = (TextView)findViewById(R.id.textView);

		switch (id) {
		case ALERT_DIALOG_ID:
			//All three buttons will have the same OnClickListener object.
			DialogInterface.OnClickListener onClickListener = new DialogInterface.OnClickListener() {

				@Override
				public void onClick(DialogInterface dialog, int id) {
					switch (id) {
					case DialogInterface.BUTTON_POSITIVE:
						textView.setText("Yes, life has a meaning.");
						break;

					case DialogInterface.BUTTON_NEUTRAL:
						textView.setText("Maybe life has a meaning.");
						break;

					case DialogInterface.BUTTON_NEGATIVE:
						textView.setText("No, life has no meaning.");
						break;

					default:
						textView.setText("Unknown id " + id + ".");
						break;
					}
				}
			};
				
			AlertDialog.Builder builder = new AlertDialog.Builder(this);

			//Generic icon: exclamation point in triangle
			builder.setIconAttribute(android.R.attr.alertDialogIcon);

			//Generic title: "Attention"
			builder.setTitle(android.R.string.dialog_alert_title);

			//Overridden in onPrepareDialog.
			builder.setMessage("Does life have a meaning?");

			//Three flavors of buttons, at most one button of each flavor.
			builder.setPositiveButton("Yes", onClickListener);
			builder.setNeutralButton("Maybe", onClickListener);
			builder.setNegativeButton("No", onClickListener);

			//Was the Android back button pressed?
			builder.setOnCancelListener(new DialogInterface.OnCancelListener() {
				@Override
				public void onCancel(DialogInterface dialog) {
					Toast.makeText(AlertDialogActivity.this,
						"Dialog cancelled.", Toast.LENGTH_LONG).show();
				}
			});

			AlertDialog alertDialog = builder.create();

			alertDialog.setOnDismissListener(new DialogInterface.OnDismissListener() {
				@Override
				public void onDismiss(DialogInterface dialog) {
					Toast.makeText(AlertDialogActivity.this,
						"Dialog dismissed.", Toast.LENGTH_LONG).show();
				}
			});

			return alertDialog;
				
		default:
			return null;
		}
	}
	
	@Override
	protected void onPrepareDialog(int id, Dialog dialog, Bundle bundle) {
		switch (id) {
		case ALERT_DIALOG_ID:
			String suffix = ++i == 1 ? "st" : i == 2 ? "nd" : i == 3 ? "rd" : "th";
			String message = String.format("For the %d%s time, does life have a meaning?", i, suffix);
			((AlertDialog)dialog).setMessage(message);

		default:
			break;
		}
	}
}